==> dusk-icons-0.1.8.tgz: package/README.md <==
# Dusk

simple, customizable macOS application icons.

<p align="center">
  <img height="100" width="100" src="https://github.com/pacocoursey/Dusk/blob/master/assets/safari.png?raw=true">
  <img height="100" width="100" src="https://github.com/pacocoursey/Dusk/blob/master/assets/hyper.png?raw=true">
  <img height="100" width="100" src="https://github.com/pacocoursey/Dusk/blob/master/assets/atom.png?raw=true">
</p>

## Install

Dusk icons can be used from the command line, via the [Dusk website](https://dusk.now.sh), or as React components [(dusk-react)](https://github.com/pacocoursey/dusk-react).

### CLI [![npm version](https://badge.fury.io/js/dusk-icons.svg)](https://badge.fury.io/js/dusk-icons)

Install the command line tool using npm:

```bash
$ [sudo] npm install -g dusk-icons
```

Then run `dusk-icons` from the command line. Enter a list of comma separated icons.

<p align="center">
  <img src="assets/example.gif" width="500px" />
</p>

## Contributing

For info on how to contribute to Dusk, please see the [contribution guidelines](https://github.com/pacocoursey/dusk/blob/master/CONTRIBUTING.md).

## Examples

![Dusk Customized Dock Example](assets/dock.png)
![Dusk Customized Dock Example 2](assets/dock2.png)

## Related

- [LiteIcon](https://freemacsoft.net/liteicon/): app which allows you to change your system icons.
- [Feather](https://github.com/colebemis/feather): Simple, beautiful open source icons.

## Icons

| Application | Icon Name | Alternates |
| :---------- | :-------- | :--------- |
| 1Password    | `1password`  |
| Ableton    | `ableton`  |
| Activity Monitor    | `activity_monitor`  |
| Affinity | `affinity` |
| Anki | `anki` |
| Adobe Illustrator | `illustrator` |
| Adobe Lightroom | `lightroom` |
| Adobe Photoshop | `photoshop` |
| App Store | `app_store` |
| Atom | `atom` |
| Books | `books` |
| Calculator | `calculator` |
| Calendar | `calendar` |
| Camera | `camera` |
| Chess | `chess` |
| Console | `console` |
| Contacts | `contacts` |
| Dashboard | `dashboard` |
| Dictionary | `dictionary` |
| Discord | `discord` |
| Dotgrid | `dotgrid` |
| Dropbox | `dropbox` |
| Electron | `electron` |
| Enpass | `enpass` |
| Facetime | `facetime` |
| Figma | `figma` |
| Finder | `finder` | `finder2`, `finder3` |
| Firefox | `firefox` |
| Font Book | `font_book` |
| Framer | `framer` |
| Franz | `franz` |
| Git | `branch` |
| Git Fork | `fork` |
| Google Chrome | `chrome` | `chrome2` |
| Hyper | `hyper` |
| iMovie | `imovie` |
| iTerm2 | `iterm2` |
| iTunes | `itunes` |
| Launchpad | `launchpad` |
| Left | `left` |
| Mail | `mail` |
| Maps | `maps` |
| Messages | `messages` |
| MongoDB Compass | `mongodb` |
| Microsoft Teams | `teams` |
| News | `news` |
| Notes | `notes` |
| Notion | `notion` |
| Numbers | `numbers` |
| OBS | `obs` |
| Pages | `pages` |
| Photos | `photos` |
| Postman | `postman` |
| Preview | `preview` |
| Quicktime Player | `quicktime` |
| Reminders | `reminders` |
| Safari | `safari` |
| Sequel Pro | `sequel_pro` |
| Sketch | `sketch` |
| Skype | `skype` |
| Slack | `slack` | `slack2` |
| SnippetsLab | `snippetslab` |
| Spotify | `spotify` |
| Steam | `steam` |
| System Preferences | `system_preferences` |
| Telegram | `telegram` |
| Terminal | `terminal` |
| Todoist | `todoist` |
| Transmit | `transmit` |
| Trash | `trash` |
| Trello | `trello` |
| Vivaldi | `vivaldi` |
| VLC | `vlc` |
| VSCode | `vscode` |
| Whatsapp | `whatsapp` |
| Xcode | `xcode` |

==> dusk-icons-0.1.11.tgz: package/README.md <==
# Dusk

simple, customizable macOS application icons.

<p align="center">
  <img height="100" width="100" src="https://github.com/pacocoursey/Dusk/blob/master/assets/safari.png?raw=true">
  <img height="100" width="100" src="https://github.com/pacocoursey/Dusk/blob/master/assets/hyper.png?raw=true">
  <img height="100" width="100" src="https://github.com/pacocoursey/Dusk/blob/master/assets/atom.png?raw=true">
</p>

## Install

Dusk icons can be used from the command line, via the [Dusk website](https://dusk.now.sh), or as React components [(dusk-react)](https://github.com/pacocoursey/dusk-react).

### CLI [![npm version](https://badge.fury.io/js/dusk-icons.svg)](https://badge.fury.io/js/dusk-icons)

Install the command line tool using npm:

```bash
$ [sudo] npm install -g dusk-icons
```

Then run `dusk-icons` from the command line. Enter a list of comma separated icons.

<p align="center">
  <img src="assets/example.gif" width="500px" />
</p>

## Contributing

For info on how to contribute to Dusk, please see the [contribution guidelines](https://github.com/pacocoursey/dusk/blob/master/CONTRIBUTING.md).

## Examples

![Dusk Customized Dock Example](assets/dock.png)
![Dusk Customized Dock Example 2](assets/dock2.png)

## Related

- [LiteIcon](https://freemacsoft.net/liteicon/): app which allows you to change your system icons.
- [Feather](https://github.com/colebemis/feather): Simple, beautiful open source icons.

## Icons

| Application | Icon Name | Alternates |
| :---------- | :-------- | :--------- |
| 1Password    | `1password`  |
| Ableton    | `ableton`  |
| Activity Monitor    | `activity_monitor`  |
| Affinity | `affinity` | `affinity_designer`, `affinity_photo`, `affinity_publisher` |
| Anki | `anki` |
| Adobe Illustrator | `illustrator` |
| Adobe Lightroom | `lightroom` |
| Adobe Photoshop | `photoshop` |
| App Store | `app_store` |
| Atom | `atom` |
| Bear | `bear` |
| Books | `books` |
| Calculator | `calculator` |
| Calendar | `calendar` |
| Camera | `camera` |
| Chess | `chess` |
| Console | `console` |
| Contacts | `contacts` |
| Dashboard | `dashboard` |
| Dictionary | `dictionary` |
| Discord | `discord` |
| Dotgrid | `dotgrid` |
| Dropbox | `dropbox` |
| Electron | `electron` |
| Enpass | `enpass` |
| Facetime | `facetime` |
| Figma | `figma` |
| Finder | `finder` | `finder2`, `finder3` |
| Firefox | `firefox` |
| Font Book | `font_book` |
| Framer | `framer` |
| Franz | `franz` |
| Git | `branch` |
| Git Fork | `fork` |
| GitHub Desktop | `github_desktop` |
| Google Chrome | `chrome` | `chrome2` |
| Hyper | `hyper` |
| iMovie | `imovie` |
| iTerm2 | `iterm2` |
| iTunes | `itunes` |
| Launchpad | `launchpad` |
| Left | `left` |
| Mail | `mail` |
| Maps | `maps` |
| Messages | `messages` |
| Facebook Messenger | `messenger` |
| MongoDB Compass | `mongodb` |
| Microsoft Teams | `teams` |
| News | `news` |
| Notes | `notes` |
| Notion | `notion` |
| Numbers | `numbers` |
| OBS | `obs` |
| Pages | `pages` |
| Photos | `photos` |
| Postman | `postman` |
| Preview | `preview` |
| Quicktime Player | `quicktime` |
| Quip | `quip` |
| Reminders | `reminders` |
| Safari | `safari` |
| Sequel Pro | `sequel_pro` |
| Sketch | `sketch` |
| Skype | `skype` |
| Slack | `slack` | `slack2` |
| SnippetsLab | `snippetslab` |
| Spark | `spark`
| Spotify | `spotify` |
| Steam | `steam` |
| System Preferences | `system_preferences` |
| Telegram | `telegram` |
| Terminal | `terminal` |
| Todoist | `todoist` |
| Transmit | `transmit` |
| Trash | `trash` |
| Trello | `trello` |
| Vivaldi | `vivaldi` |
| VLC | `vlc` |
| VSCode | `vscode` |
| Whatsapp | `whatsapp` |
| Xcode | `xcode` |
